#!/bin/sh
#
# GSI configuration script
# Wowzers! Look at all the options Penny!

cd Config
# default/other script
Ask="sh ./Choose.sh"



# Figure out what kind of system we are on:
system=`uname`
if [ "X$system" = "X" ]; then
  echo "uname failed!"
else
  echo System=$system
fi



# initialize a few things
cc="gcc"

# Default: full optimization:
optimize="-O2 -fomit-frame-pointer"

extraobjs=""
extralibs=""



# All the configuration options:
echo "/* GSI configuration created by Configure.sh */" >../config.h

D="#define "
U="#undef"

echo "$D SYSTEM_$system" >>../config.h


#BYTE_ORDER
if [ "X$system" = "XOpenBSD" ]; then
#	OpenBSD: defined in <stdio.h> -> <sys/types.h> -> <machine/endian.h>
	echo "#include <stdio.h>" >>../config.h
elif [ "X$system" = "XLinux" ]; then
#	Linux: defined in <endian.h>
	echo "#include <endian.h>" >>../config.h
elif [ "`$Ask 'Is your machine little endian (intel) ?' 'y'`" != "n" ]; then
	echo "$D LITTLE_ENDIAN_MACHINE" >>../config.h
	features="$features -DLITTLE_ENDIAN_MACHINE"
fi
if [ "X$system" = "XOpenBSD" ] || [ "X$system" = "XLinux" ]; then
	echo "#if BYTE_ORDER==LITTLE_ENDIAN" >>../config.h
	echo "$D LITTLE_ENDIAN_MACHINE" >>../config.h
	echo "#endif" >>../sysconfig.h
fi


echo "Which audio system API?"
echo "  1. OSS (open sound system)"
echo "  2. NAS (network audio system) INCOMPLETE"
echo "  3. alsa (advanced linux sound architecture) UNIMPLEMENTED"
echo "  4. new bsd driver UNIMPLEMENTED"
echo "  5. generic /dev/audio (8 kHz mono mulaw) => not tested, let me know if it works!"
api_choice="0"
while [ "$api_choice" = "0" ]; do
#  echo "$api_choice"
  api_choice="`$Ask "Which one? " '1'`"
  case $api_choice in
    1 ) echo "Using OSS"
	api_choice="1"
	features="$features -DUSE_OSS"
	echo "$D USE_OSS" >>../config.h
	echo "$U USE_NAS" >>../config.h
	echo "$U USE_ALSA" >>../config.h
	echo "$U USE_NEW_BSD" >>../config.h
	echo "$U USE_DEV_AUDIO" >>../config.h
	echo "$D MIXER_DEV \"/dev/mixer\"" >>../config.h
	echo "$D DSP_DEV \"/dev/dsp\"" >>../config.h
	use_sndserver="YES"
	#	sndserver="gsi_server"
	;;
    2 ) echo "Using NAS"
	api_choice="2"
	#	screenflags="$screenflags -DNAS_SOUND"
	#	features="$features -DUSE_SOUND -DUSE_NAS"
	features="$features -DUSE_NAS"
	echo "$U USE_OSS" >>../config.h
	echo "$D USE_NAS" >>../config.h
	echo "$U USE_ALSA" >>../config.h
	echo "$U USE_NEW_BSD" >>../config.h
	echo "$U USE_DEV_AUDIO" >>../config.h
	extralibs="$extralibs \$(NASLIBS)"
	use_sndserver="NO"
	sndserver=""
	;;
    3 ) echo "Using alsa"
	api_choice="3"
	features="$features -DUSE_ALSA"
	echo "$U USE_OSS" >>../config.h
	echo "$U USE_NAS" >>../config.h
	echo "$D USE_ALSA" >>../config.h
	echo "$U USE_NEW_BSD" >>../config.h
	echo "$U USE_DEV_AUDIO" >>../config.h
	echo "$D MIXER_DEV \"/dev/mixer\"" >>../config.h
	echo "$D DSP_DEV \"/dev/dsp\"" >>../config.h
	use_sndserver="YES"
	#	sndserver="gsi_server"
	;;
    4 ) echo "Using new bsd driver"
	api_choice="4"
	features="$features -DUSE_NEW_BSD"
	echo "$U USE_OSS" >>../config.h
	echo "$U USE_NAS" >>../config.h
	echo "$U USE_ALSA" >>../config.h
	echo "$D USE_NEW_BSD" >>../config.h
	echo "$U USE_DEV_AUDIO" >>../config.h
	echo "$D MIXER_DEV \"/dev/mixer\"" >>../config.h
	echo "$D DSP_DEV \"/dev/dsp\"" >>../config.h
	use_sndserver="YES"
	#	sndserver="gsi_server"
	;;
    5 ) echo "Using generic /dev/audio"
	api_choice="5"
	features="$features -DUSE_DEV_AUDIO"
	echo "$U USE_OSS" >>../config.h
	echo "$U USE_NAS" >>../config.h
	echo "$U USE_ALSA" >>../config.h
	echo "$U USE_NEW_BSD" >>../config.h
	echo "$D USE_DEV_AUDIO" >>../config.h
	echo "$D MIXER_DEV \"/dev/mixer\"" >>../config.h
	echo "$D DSP_DEV \"/dev/audio\"" >>../config.h
	use_sndserver="YES"
	#	sndserver="gsi_server"
	;;

    * ) echo "Bad choice"
	api_choice="0"
	;;
  esac
done

if [ $api_choice = "1" ] || [ $api_choice = "2" ]; then
#  use_opl3=0
#  use_gus=0
#  use_awe32=0
# OPL3 support?
if [ "`$Ask 'Do you want OPL3 synth support?' 'y'`" != "n" ]; then
#	extraobjs="$extraobjs font6x8.o"
	echo "$D USE_OPL3_SYNTH" >>../config.h
	use_opl3=1
fi

# GUS support?
if [ "`$Ask 'Do you want GUS synth support?' 'y'`" != "n" ]; then
	echo "$D USE_GUS_SYNTH" >>../config.h
	use_gus=1
fi

# AWE32 support?
if [ "`$Ask 'Do you want AWE32 synth support?' 'y'`" != "n" ]; then
	echo "$D USE_AWE32_SYNTH" >>../config.h
	use_awe32=1
fi

if [ $use_gus ]; then
	gus_patch_dir=/dos/ultrasnd/midi
	gus_patch_dir="`$Ask 'Where search for the patches?' $gus_patch_dir`"
	echo "$D GUS_PATCH_DIR \"$gus_patch_dir\"" >>../config.h

	if [ "`$Ask 'Do you want to compile in all patches (tremolo/vox)?' 'y'`" != "n" ]; then
	echo "$D GUS_HAVE_ALL_PATCHES" >>../config.h
fi
fi

fi #api_choice="1"

# Check the compiler
cc=`$Ask 'What compiler do you want to use?' "$cc"`
optimize=`$Ask 'What optimization flags do you want to use?' "$optimize"`

# Create a new Makeflags file
echo
echo "Creating new Makeflags..."
sed <Makeflags.in >Makeflags \
	-e "s|^\\(SYSTEM =\\)\$|\\1 $system|" \
	-e "s|^\\(CC =\\)\$|\\1 $cc|" \
	-e "s|^\\(OPTIMIZE =\\)\$|\\1 $optimize|" \
	-e "s|^\\(FEATURES =\\)\$|\\1 $features|" \
	-e "s|^\\(EXTRALIBS =\\)\$|\\1 $extralibs|" \
	-e "s|^\\(SOUNDLIBS =\\)\$|\\1 $soundlibs|" \
	-e "s|^\\(EXTRAOBJS =\\)\$|\\1 $extraobjs|" \
	-e "s|^\\(USE_SNDSERVER =\\)\$|\\1 $use_sndserver|" \
	-e "s|^\\(SNDSERVER =\\)\$|\\1 $sndserver|"
echo

echo "Now type 'make clean' and 'make' to build GSI"
